paper-tabs

### A. No ink effect and no sliding bar

ITEM ONE ITEM TWO ITEM THREE

### B. The bottom bar appears to indicate the selected tab, but without sliding effect.

ITEM ONE ITEM TWO ITEM THREE

### C. The bar slides to the selected tab

ITEM ONE ITEM TWO ITEM THREE

### D. Inky Tabs

ITEM ONE ITEM TWO ITEM THREE
ITEM ONE ITEM TWO ITEM THREE

### E. Scrollable Tabs

NUMBER ONE ITEM ITEM TWO THE THIRD ITEM THE ITEM FOUR FIFTH THE SIXTH TAB NUMBER SEVEN EIGHT NUMBER NINE THE TENTH THE ITEM ELEVEN TWELFTH ITEM

### F. Link Tabs

ITEM ONE ITEM TWO ITEM THREE

### G. Tabs in Toolbar

Title
ITEM ONE ITEM TWO ITEM THREE
ITEM ONE ITEM TWO